==> genai_apis-0.0.5-py3-none-any.whl: genai_apis/gemini_api.py <==
import asyncio
from .abstract import TextGenerationAPI


async def _word_generator(sentence):
    for word in sentence.split(" "):
        yield word + " "
        delay = 0.03 + (len(word) * 0.005)
        await asyncio.sleep(delay)  # Simulate a short delay


async def _get_stream_outputs(response):
    async for chunk in response:
        async for word in _word_generator(chunk.text):
            yield word


class GeminiAPI(TextGenerationAPI):
    async def generate_text(self, model, prompt, system_instruction=None, **kwargs):
        import google.generativeai as genai

        generation_config = genai.types.GenerationConfig(**kwargs)

        model = genai.GenerativeModel(
            model_name=model, system_instruction=system_instruction
        )
        response = await model.generate_content_async(
            [prompt], generation_config=generation_config
        )

        if "stream" in kwargs and kwargs["stream"] is True:
            return _get_stream_outputs(response)
        else:
            return response.text


class GeminiVertexAPI(TextGenerationAPI):
    async def generate_text(self, model, prompt, system_instruction=None, **kwargs):
        from vertexai.generative_models import GenerativeModel

        generation_config = GenerativeModel.GenerationConfig(**kwargs)
        model = GenerativeModel(model_name=model, system_instruction=system_instruction)
        response = await model.generate_content_async(
            [prompt], generation_config=generation_config
        )

        if "stream" in kwargs and kwargs["stream"] is True:
            return _get_stream_outputs(response)
        else:
            return response.text

==> genai_apis-0.0.6-py3-none-any.whl: genai_apis/gemini_api.py <==
import asyncio
from .abstract import TextGenerationAPI


async def _word_generator(sentence):
    for word in sentence.split(" "):
        yield word + " "
        delay = 0.03 + (len(word) * 0.005)
        await asyncio.sleep(delay)  # Simulate a short delay


async def _get_stream_outputs(response):
    async for chunk in response:
        async for word in _word_generator(chunk.text):
            yield word


class GeminiAPI(TextGenerationAPI):
    async def generate_text(self, model, prompt, system_instruction=None, **kwargs):
        import google.generativeai as genai

        generation_config = genai.types.GenerationConfig(**kwargs)

        model = genai.GenerativeModel(
            model_name=model, system_instruction=system_instruction
        )
        response = await model.generate_content_async(
            [prompt], generation_config=generation_config
        )

        if "stream" in kwargs and kwargs["stream"] is True:
            return _get_stream_outputs(response)
        else:
            return response.text


class GeminiVertexAPI(TextGenerationAPI):
    async def generate_text(self, model, prompt, system_instruction=None, **kwargs):
        from vertexai.generative_models import GenerativeModel
        from vertexai import generative_models

        generation_config = generative_models.GenerationConfig(**kwargs)
        model = GenerativeModel(model_name=model, system_instruction=system_instruction)
        response = await model.generate_content_async(
            [prompt], generation_config=generation_config
        )

        if "stream" in kwargs and kwargs["stream"] is True:
            return _get_stream_outputs(response)
        else:
            return response.text
